@@ -155,7 +155,8 @@ MESSAGES = {
     "create this path:",
     "url_unreachable": "The following url was unreachable:",
     "yaml_error": "%file contains 1 or more syntax errors:",
-    "template_error": "%file contains 1 or more syntax errors:",
+    "template_error": "Your template(s) contain 1 or more syntax errors:",
+    "template_extender_missing": "The following template could not be found:",
     "png_missing_out": "You must supply -o <file> to write the png file",
     "dot_missing": "To export a PNG graph you must install graphviz",
     "run_success": "%role_count roles were modified with this shell command:",
